# Copyright (C) 2011 by Canonical Ltd.
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.

import os

from twisted.trial import unittest
from txsymmetricjsonrpc import parser


class BasicTests(unittest.TestCase):
    def setUp(self):
        self.s = parser.Stream()

    def tearDown(self):
        self.s.close()

    def test_oneChunkOneObject(self):
        self.s.addData('{"a": 1}')

        self.assertEquals(self.s.nextObject(), {"a": 1})

        self.assertFalse(self.s.hasObject())

    def test_oneChunkManyObjects(self):
        self.s.addData('{"a": 1}{"b": 2}')

        self.assertEquals(self.s.nextObject(), {"a": 1})
        self.assertEquals(self.s.nextObject(), {"b": 2})

        self.assertFalse(self.s.hasObject())

    def test_partial(self):
        self.s.addData('{"a"')
        self.assertFalse(self.s.hasObject())

        self.s.addData(': 1}{"b": 2}')

        self.assertEquals(self.s.nextObject(), {"a": 1})
        self.assertEquals(self.s.nextObject(), {"b": 2})

        self.assertFalse(self.s.hasObject())
